package com.ruoyi.project.plant.service;

import java.util.List;
import com.ruoyi.project.plant.domain.TMtPerson;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.apache.poi.xwpf.usermodel.XWPFRun;

/**
 * 会议人员Service接口
 *
 * @author ruoyi
 * @date 2021-01-14
 */
public interface ITMtPersonService
{
    /**
     * 查询会议人员
     *
     * @param id 会议人员ID
     * @return 会议人员
     */
    public TMtPerson selectTMtPersonById(Long id);

    /**
     * 查询会议人员列表
     *
     * @param tMtPerson 会议人员
     * @return 会议人员集合
     */
    public List<TMtPerson> selectTMtPersonList(TMtPerson tMtPerson);

    /**
     * 新增会议人员
     *
     * @param tMtPerson 会议人员
     * @return 结果
     */
    public int insertTMtPerson(TMtPerson tMtPerson);

    /**
     * 修改会议人员
     *
     * @param tMtPerson 会议人员
     * @return 结果
     */
    public int updateTMtPerson(TMtPerson tMtPerson);

    /**
     * 批量删除会议人员
     *
     * @param ids 需要删除的会议人员ID
     * @return 结果
     */
    public int deleteTMtPersonByIds(Long[] ids);

    /**
     * 删除会议人员信息
     *
     * @param id 会议人员ID
     * @return 结果
     */
    public int deleteTMtPersonById(Long id);

    void dealPerson1(XWPFDocument doc, XWPFParagraph paragraph, XWPFRun run, Long meetingId);

    void dealPerson2(XWPFDocument doc, XWPFParagraph paragraph, XWPFRun run, Long meetingId);
}
